@@ -41,6 +41,7 @@ enum connman_device_type {
 	CONNMAN_DEVICE_TYPE_WIFI      = 2,
 	CONNMAN_DEVICE_TYPE_WIMAX     = 3,
 	CONNMAN_DEVICE_TYPE_BLUETOOTH = 4,
+	CONNMAN_DEVICE_TYPE_GPS       = 5,
 	CONNMAN_DEVICE_TYPE_HSO       = 15,
 	CONNMAN_DEVICE_TYPE_NOZOMI    = 16,
 	CONNMAN_DEVICE_TYPE_HUAWEI    = 17,
@@ -83,6 +84,7 @@ extern void connman_device_set_policy(struct connman_device *device,
 					enum connman_device_policy policy);
 extern void connman_device_set_mode(struct connman_device *device,
 						enum connman_device_mode mode);
+extern enum connman_device_mode connman_device_get_mode(struct connman_device *device);
 
 extern int connman_device_set_powered(struct connman_device *device,
 						connman_bool_t powered);
@@ -90,6 +92,8 @@ extern int connman_device_set_carrier(struct connman_device *device,
 						connman_bool_t carrier);
 extern int connman_device_set_scanning(struct connman_device *device,
 						connman_bool_t scanning);
+extern int connman_device_set_disconnected(struct connman_device *device,
+						connman_bool_t disconnected);
 
 extern int connman_device_set_string(struct connman_device *device,
 					const char *key, const char *value);
