@@ -298,8 +298,7 @@ static int pan_disconnect(struct connman_network *network)
 	if (message == NULL)
 		return -ENOMEM;
 
-	dbus_message_append_args(message, DBUS_TYPE_STRING, &data->interface,
-							DBUS_TYPE_INVALID);
+	dbus_message_append_args(message, DBUS_TYPE_INVALID);
 
 	if (dbus_connection_send_with_reply(data->connection, message,
 						&call, TIMEOUT) == FALSE) {
@@ -496,6 +495,8 @@ static void device_properties(DBusConnection *connection, const char *path,
 	if (network == NULL)
 		return;
 
+	connman_network_set_protocol(network, CONNMAN_NETWORK_PROTOCOL_IP);
+
 	connman_network_set_string(network, "Node", path);
 
 	connman_device_add_network(device, network);
@@ -848,4 +849,4 @@ static void bluetooth_exit(void)
 }
 
 CONNMAN_PLUGIN_DEFINE(bluetooth, "Bluetooth technology plugin", VERSION,
-						bluetooth_init, bluetooth_exit)
+		CONNMAN_PLUGIN_PRIORITY_DEFAULT, bluetooth_init, bluetooth_exit)
